asr.test.mocks.gpaw.utilities.dos
=================================

.. automodule:: asr.test.mocks.gpaw.utilities.dos

   
   
   .. rubric:: Functions

   
   .. autofunction:: raw_orbital_LDOS
   
   

   
   
   

   
   
   